# eric7.Plugins.VcsPlugins.vcsGit.GitListDialog

Module implementing a dialog to select from a list.

### Global Attributes

None

### Classes

GitListDialog | Class implementing a dialog to select from a list.

### Functions

None

## GitListDialog

Class implementing a dialog to select from a list.

### Derived from

QDialog, Ui_GitListDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitListDialog | Constructor
getSelection | Public method to return the selected entries.

### Static Methods

None

#### GitListDialog (Constructor)

GitListDialog(selections, parent=None)

Constructor

selections
  list of entries to select from (list of string)
parent
  reference to the parent widget (QWidget)

#### GitListDialog.getSelection

getSelection()

Public method to return the selected entries.

Return:
  list of selected entries (list of string)

Up